@@ -418,7 +418,7 @@ class Macast(App):
                                                   ], self.on_menubar_icon_change_click))
         self.open_config_menuitem = MenuItem(_("Open Config Directory"), self.on_open_config_click)
         self.check_update_menuitem = MenuItem(_("Check For Updates"), self.on_check_click)
-        self.about_menuitem = MenuItem(_("About"), self.on_about_click)
+        self.about_menuitem = MenuItem(_("Help"), self.on_about_click)
 
         self.menubar_icon_menuitem.items()[self.setting_menubar_icon].checked = True
         player_settings = self.dlna_service.renderer.renderer_setting.build_menu()
@@ -535,7 +535,8 @@ class Macast(App):
 
     def renderer_av_stop(self):
         logger.info("renderer_av_stop")
-        self.remove_menu_item_by_id(self.copy_menuitem.id)
+        if self.copy_menuitem:
+            self.remove_menu_item_by_id(self.copy_menuitem.id)
         self.copy_menuitem = None
 
     def renderer_start(self):
@@ -544,6 +545,7 @@ class Macast(App):
     def renderer_av_uri(self, uri):
         logger.info("renderer_av_uri: " + uri)
         if self.copy_menuitem is not None:
+            self.copy_menuitem.callback = lambda _: pyperclip.copy(uri)
             return
         self.copy_menuitem = MenuItem(
             _("Copy Video URI"),
@@ -586,7 +588,7 @@ class Macast(App):
             self.notification(_("Error"), _(res[1]))
 
     def on_about_click(self, _):
-        self.open_browser('https://github.com/xfangfang/Macast')
+        self.open_browser('https://xfangfang.github.io/Macast/')
 
     def on_toggle_service_click(self, item):
         if Setting.is_service_running():
@@ -611,11 +613,13 @@ class Macast(App):
 
 def gui(renderer=None, lang=gettext.gettext):
     if renderer is None:
+        Setting.load()
         renderer = MPVRenderer(lang)
     Macast(renderer, lang).start()
 
 
 def cli(renderer=None):
     if renderer is None:
+        Setting.load()
         renderer = MPVRenderer()
     Service(renderer).run()
