@@ -58,6 +58,7 @@ class MPVRenderer(Renderer):
             self.mpv_sock = '/tmp/macast_mpvsocket{}'.format(mpv_rand)
         self.path = path
         self.proc = None
+        self.title = Setting.get_friendly_name()
         self.mpv_thread = None
         self.ipc_thread = None
         self.ipc_sock = None
@@ -99,6 +100,7 @@ class MPVRenderer(Renderer):
     def set_media_title(self, data):
         """ data : string
         """
+        self.title = data
         self.send_command(['set_property', 'title', data])
 
     def set_media_position(self, data):
@@ -408,6 +410,7 @@ class MPVRenderer(Renderer):
         def loadfile():
             logger.debug("mpv loadfile")
             self.send_command(['loadfile', uri, 'replace'])
+            self.send_command(['set_property', 'title', self.title])
             cherrypy.engine.unsubscribe('mpvipc_start', loadfile)
 
         def resatrt():
@@ -422,19 +425,19 @@ class MPVRenderer(Renderer):
 
 
 class SettingProperty(Enum):
-    PlayerHW = 1
+    PlayerHW = 100
     PlayerHW_Disable = 0
     PlayerHW_Enable = 1
     PlayerHW_Force = 2
 
-    PlayerSize = 2
+    PlayerSize = 200
     PlayerSize_Small = 0
     PlayerSize_Normal = 1
     PlayerSize_Large = 2
     PlayerSize_Auto = 3
     PlayerSize_FullScreen = 4
 
-    PlayerPosition = 3
+    PlayerPosition = 300
     PlayerPosition_LeftTop = 0
     PlayerPosition_LeftBottom = 1
     PlayerPosition_RightTop = 2
